package com.lyg.application.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.application.entity.TaMessage;
import com.lyg.application.service.TaMessageService;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.accesslimit.AccessLimit;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 消息表;(ta_massage)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2024-3-14
 */
@Api(tags = "消息表对象功能接口")
@RestController
@RequestMapping("/")
public class TaMessageController extends BaseController {

    @Autowired
    private TaMessageService taMessageService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "消息表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taMessage/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        TaMessage taMessage = taMessageService.getById(id);


        System.out.println("checkAuth()" + checkAuth());
        Boolean b = checkAuth() == null || checkAuth() == taMessage.getCreateUser();

        if (b) {
            return SaResult.data(taMessageService.getById(id));
        }
        return SaResult.error("无权限");
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "消息表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/taMessage")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("来源表") @RequestParam(value = "sourceName", required = false) String sourceName,
                         @ApiParam("内容") @RequestParam(value = "contentSent", required = false) String contentSent,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "create_date") String sortDesc) throws Exception {

        IPage<TaMessage> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaMessage> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtil.isNotEmpty(checkAuth()), "CREATE_USER", checkAuth());
        queryWrapper.eq(StringUtil.isNotEmpty(sourceName), "SOURCE_NAME", sourceName);
        queryWrapper.like(StringUtil.isNotEmpty(contentSent), "content_sent", contentSent);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<TaMessage> result = taMessageService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param taMessage 实例对象
     * @return 实例对象
     */
    @OpLog(module = "消息表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/taMessage")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody TaMessage taMessage) throws Exception {
        taMessageService.save(taMessage);
        return SaResult.data(taMessage);
    }

    /**
     * 更新数据
     *
     * @param taMessage 实例对象
     * @return 实例对象
     */
    @OpLog(module = "消息表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/taMessage/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody TaMessage taMessage,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        taMessage.setMessageId(id);
        taMessageService.updateById(taMessage);
        return SaResult.data(taMessage);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "消息表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taMessage/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taMessageService.removeById(id);
        return SaResult.data("success");
    }
}