package com.lyg.application.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.application.entity.TaSending;
import com.lyg.application.service.TaSendingService;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.accesslimit.AccessLimit;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 发送消息;(ta_sending)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2024-3-14
 */
@Api(tags = "发送消息对象功能接口")
@RestController
@RequestMapping("/")
public class TaSendingController extends BaseController {

    @Autowired
    private TaSendingService taSendingService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "发送消息", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taSending/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        TaSending taSending = taSendingService.getById(id);

        Boolean b = checkAuth() == null || checkAuth() == taSending.getCreateUser();
        if (b) {
            return SaResult.data(taSendingService.getById(id));
        }
        return SaResult.error("无权限");


    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "发送消息", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/taSending")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "create_date") String sortDesc) throws Exception {
        IPage<TaSending> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSending> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtil.isNotEmpty(checkAuth()), "RECIPIENT_ID", checkAuth());
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<TaSending> result = taSendingService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param taSending 实例对象
     * @return 实例对象
     */
    @OpLog(module = "发送消息", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/taSending")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody TaSending taSending) throws Exception {
        taSendingService.save(taSending);
        return SaResult.data(taSending);
    }

    /**
     * 更新数据
     *
     * @param taSending 实例对象
     * @return 实例对象
     */
    @OpLog(module = "发送消息", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/taSending/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody TaSending taSending,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        taSending.setSendingId(id);
        taSendingService.updateById(taSending);
        return SaResult.data(taSending);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "发送消息", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taSending/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taSendingService.removeById(id);
        return SaResult.data("success");
    }
}