package com.lyg.application.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.format.DateTimeFormat;
import com.lyg.common.util.excel.LocalDateConverter;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.baomidou.mybatisplus.annotation.*;
import java.io.Serializable;
import java.time.LocalDate;
import java.time.LocalDateTime;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import javax.validation.constraints.NotBlank;

 /**
 * 强制休假表;
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = false)
@ApiModel(value = "强制休假表",description = "")
@TableName("ta_mandatory_leave")
public class TaMandatoryLeave implements Serializable,Cloneable{
    
    @ApiModelProperty(name = "轮岗Id",notes = "")
    @TableId(value = "leave_id", type = IdType.ASSIGN_UUID)
    private String leaveId ;

     @ExcelProperty(index = 1)
     @ApiModelProperty(name = "总行部门/一级分行",notes = "")
    private String headOfficeOrg ;

     @ExcelProperty(index = 2)
     @ApiModelProperty(name = "员工工号",notes = "")
    private String employeeNum ;

     @ExcelProperty(index = 3)
     @NotBlank(message = "员工姓名不能为空")
    @ApiModelProperty(name = "员工姓名",notes = "")
    private String employeeName ;

     @ExcelProperty(index = 4)
     @ApiModelProperty(name = "所在单位机构号",notes = "")
    private String orgNum ;

     @ExcelProperty(index = 5)
     @NotBlank(message = "所在单位名称不能为空")
    @ApiModelProperty(name = "所在单位名称",notes = "")
    private String orgName ;

     @ExcelProperty(index = 6)
     @ApiModelProperty(name = "对应机构层次",notes = "")
    private String counterInstitutionsLevel ;

     @ExcelProperty(index = 7)
     @ApiModelProperty(name = "当前职位",notes = "")
    private String currentPosition ;

     @ExcelProperty(index = 8)
     @ApiModelProperty(name = "对应重要岗位",notes = "")
    private String counterImpPost ;

     @ExcelProperty(index = 9)
     @ApiModelProperty(name = "对应总行条线",notes = "")
    private String counterHeadOfficeLine ;

     @ExcelProperty(index = 10, converter = LocalDateConverter.class)
//     @DateTimeFormat("yyyy/MM/dd")
     @ApiModelProperty(name = "休假起始时间 格式：年/月/日",notes = "")
    private LocalDate startTimeVacation ;

     @ExcelProperty(index = 11, converter = LocalDateConverter.class)
//     @DateTimeFormat("yyyy/MM/dd")
     @ApiModelProperty(name = "休假截止时间 格式：年/月/日",notes = "")
    private LocalDate vacationDeadline ;

     @ExcelProperty(index = 12)
     @ApiModelProperty(name = "已强制休假天数（工作日）",notes = "")
    private Integer mandatoryVacationDay ;

     @ExcelProperty(index = 13)
     @ApiModelProperty(name = "开展离岗检查/代职检查情况",notes = "")
    private String depSbtDepartureCheck ;

     @ExcelProperty(index = 14)
    @ApiModelProperty(name = "备注",notes = "")
    private String remark ;

     @ExcelProperty(index = 15)
     @ApiModelProperty(name = "立查立改(是/否）",notes = "")
    private String checkChange ;

     @ExcelProperty(index = 16)
     @ApiModelProperty(name = "自查自纠 (是/否）",notes = "")
    private String checkCorrect ;

    @ExcelProperty(index = 0)
    @ApiModelProperty(name = "序号",notes = "")
    private String sort ;
    
    @ApiModelProperty(name = "状态",notes = "")
    private Integer status ;
    
    @ApiModelProperty(name = "创建人",notes = "")
    @TableField(fill = FieldFill.INSERT)
    private String createUser ;
    
    @ApiModelProperty(name = "创建时间",notes = "")
    @TableField(fill = FieldFill.INSERT)
    private LocalDateTime createDate ;
    
    @ApiModelProperty(name = "更新人",notes = "")
    @TableField(fill = FieldFill.INSERT_UPDATE)
    private String updateUser ;
    
    @ApiModelProperty(name = "更新时间",notes = "")
    @TableField(fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateDate ;
    
    @ApiModelProperty(name = "删除标志",notes = "1删除")
    @TableField(fill = FieldFill.INSERT)
    private Integer deleted ;

}