package com.lyg.application.service.impl;

import com.lyg.application.entity.TaMandatoryLeave;
import com.lyg.application.mapper.TaMandatoryLeaveMapper;
import com.lyg.application.mapper.TaMessageMapper;
import com.lyg.application.mapper.TaSendingMapper;
import com.lyg.application.service.TaMandatoryLeaveService;
import com.lyg.application.service.TaMessageService;
import com.lyg.application.util.MessageHandle;
import com.lyg.system.mapper.SysPositionMapper;
import com.lyg.system.mapper.SysUserMapper;
import com.lyg.system.service.SysOrgService;
import com.lyg.system.service.SysPositionService;
import com.lyg.system.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;

/**
 * 强制休假表;(ta_mandatory_leave)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Service
public class TaMandatoryLeaveServiceImpl extends BaseServiceImpl<TaMandatoryLeaveMapper, TaMandatoryLeave> implements TaMandatoryLeaveService {
    private final List<String> errorMessages = new ArrayList<>();

    private static final String MESSAGE_SOURCE_NAME = "taMandatoryLeave";
    private static final String PROMPT_TYPE = "prompt";

    @Value("${yz.holidayTmp}")
    String holidayTmp;

    @Autowired
    private SysOrgService sysOrgService;
    @Autowired
    private SysPositionService sysPositionService;
    @Autowired
    private SysPositionMapper sysPositionMapper;
    @Autowired
    private TaMessageService taMessageService;
    @Autowired
    private TaMessageMapper taMessageMapper;
    @Autowired
    private TaSendingMapper taSendingMapper;
    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private MessageHandle messageHandle;

    @Override
    public TaMandatoryLeave handleEntity(TaMandatoryLeave entity, Integer index) throws Exception {
//校验验证
        System.out.println("******************************entity**************************************");
        System.out.println(entity);

        String orgCode = entity.getOrgNum();//单位机构号
        String orgName = entity.getOrgName().replaceAll("\n", "");//单位机构名

        String counterImpPost = null;
        if (entity.getCounterImpPost() != null) {
            counterImpPost = entity.getCounterImpPost().replaceAll("\n", "");//岗位名
            //        轮岗之前岗位名  获取id
            String rotationId = sysPositionMapper.getPostId(counterImpPost);
            entity.setCounterImpPost(rotationId);
        }
        LocalDate durationOfEmployment = entity.getStartTimeVacation();
        LocalDate vacationDeadline = entity.getVacationDeadline();


        Long count = sysOrgService.countBy("org_id", orgCode, true);
        if (count == 0 || orgCode.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构号 " + orgCode);
        }

        count = sysOrgService.countBy("name", orgName, true);
        if (count == 0 || orgName.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构名字 " + orgName);
        }

        count = sysPositionService.countBy("name", counterImpPost, true);
        if (count == 0) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此岗位 " + counterImpPost);
        }

        if (durationOfEmployment == null) {
            errorMessages.add("第 " + index + " 行时间错误:休假起始时间为 " + durationOfEmployment);
        }
        if (vacationDeadline == null) {
            errorMessages.add("第 " + index + " 行时间错误:休假截止时间为 " + vacationDeadline);
        }

        return entity;
    }

    @Override
    public void saveEntityBatch(List<TaMandatoryLeave> entityList) {
        // 实现逻辑：保存批量实体
        System.out.println("******************************entityList**************************************");
        System.out.println(entityList);
        for (TaMandatoryLeave taMandatoryLeave : entityList) {
            baseMapper.insert(taMandatoryLeave);
        }
    }


    public List<String> getErrorMessages() {
        return errorMessages;

    }

    @Override
    public void selectGetPrompt() {
        LocalDate localDate = LocalDate.now();

//        messageHandle.handleMandatoryLeaves(localDate, holidayTmp, PROMPT_TYPE);
        // 提示消息处理
        messageHandle.handleMandatoryLeaves(localDate, holidayTmp, PROMPT_TYPE,MESSAGE_SOURCE_NAME, baseMapper::prompt);
//        List<TaMandatoryLeave> promptList = baseMapper.prompt(localDate);
//
//        if (promptList.size() != 0) {
//            for (TaMandatoryLeave item : promptList) {
//                Map<String,String> params = new HashMap<>();
//                TaMessage taMessage = new TaMessage();
//                String uuid = StringUtil.UUID();
//                taMessage.setMessageId(uuid);
//                taMessage.setSourceId(item.getLeaveId());
//                StringBuilder sb = new StringBuilder(holidayTmp);
//                sb.insert(Constants.numI, item.getEmployeeNum());
//                Integer i = item.getEmployeeNum().length() + Constants.nameI;
//                sb.insert(i, item.getEmployeeName());
//                taMessage.setContentSent(sb.toString());
//                taMessage.setSourceName("taMandatoryLeave");
//                taMessage.setWaringType("prompt");
//                params.put("taMandatoryLeave","taMandatoryLeave");
//                params.put("prompt","prompt");
//                params.put("stringBuilder",sb.toString());
//
//
//                Long count = taMessageService.countBy("source_id", item.getLeaveId(), true);
//                if (count == 0) {
//                    taMessageMapper.insert(taMessage);
//                    insertIntoTaSending(item.getCreateUser(), uuid);
//                }else{
//                    taMessageMapper.updateBySourceId(item.getLeaveId(),params);
//                }
//
//            }
//        }


    }


}