package com.lyg.application.service.impl;

import com.lyg.application.entity.TaRotation;
import com.lyg.application.mapper.TaMessageMapper;
import com.lyg.application.mapper.TaRotationMapper;
import com.lyg.application.mapper.TaSendingMapper;
import com.lyg.application.service.TaMessageService;
import com.lyg.application.service.TaRotationService;
import com.lyg.application.util.MessageHandle;
import com.lyg.application.util.Rule;
import com.lyg.system.mapper.SysPositionMapper;
import com.lyg.system.mapper.SysUserMapper;
import com.lyg.system.service.SysOrgService;
import com.lyg.system.service.SysPositionService;
import com.lyg.system.service.SysUserService;
import com.lyg.system.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

/**
 * 轮岗列表;(ta_rotation)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Service

public class TaRotationServiceImpl extends BaseServiceImpl<TaRotationMapper, TaRotation> implements TaRotationService {

    private static final String WARNING_TYPE = "waring";
    private static final String PROMPT_TYPE = "prompt";
    private static final String MESSAGE_SOURCE_NAME = "taRotation";
    private final List<Object> errorMessages = new ArrayList<>();
    @Autowired
    Rule rule;
    @Value("${yz.warningTmp}")
    String warningTmp;
    @Value("${yz.promptTmp}")
    String promptTmp;
    @Autowired
    private SysOrgService sysOrgService;
    @Autowired
    private SysPositionService sysPositionService;
    @Autowired
    private SysPositionMapper sysPositionMapper;
    @Autowired
    private TaMessageMapper taMessageMapper;
    @Autowired
    private TaMessageService taMessageService;
    @Autowired
    private TaSendingMapper taSendingMapper;
    @Autowired
    private SysUserService sysUserService;
    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private MessageHandle messageHandle;


    public TaRotation handleEntity(TaRotation entity, Integer index) throws Exception {
//校验验证
        System.out.println("******************************entity**************************************");
//        System.out.println(entity);

        String specificNameOrgRotation = entity.getSpecificNameOrgRotation();
        String counterImpPostRotation = entity.getCounterImpPostRotation();


        String orgCode = entity.getSpecificOrgNum();//单位机构号
        String orgName = entity.getSpecificOrgName().replaceAll("\n", "");//单位机构名
        String rotationName = entity.getCounterImpPositions().replaceAll("\n", "");//轮岗之前岗位名
        String impPostRotation = null;
        if (entity.getCounterImpPostRotation() != null) {
            impPostRotation = entity.getCounterImpPostRotation().replaceAll("\n", "");//轮岗之后岗位名
        }
        LocalDate durationOfEmployment = entity.getDurationOfEmployment();
        LocalDate rotationExeTime = entity.getRotationExeTime();
        LocalDate rotationDeadline = entity.getRotationDeadline();
        LocalDate planRotationDate = entity.getPlanRotationDate();
//        轮岗之前岗位名  获取id
        String rotationId = sysPositionMapper.getPostId(rotationName);
        entity.setCounterImpPositions(rotationId);
        if (impPostRotation != null) {
            //   轮岗之后岗位名  获取id
            String impPostRotationId = sysPositionMapper.getPostId(impPostRotation);
            entity.setCounterImpPostRotation(impPostRotationId);
        }


        Long count = sysOrgService.countBy("org_id", orgCode, true);
        if (count == 0 || orgCode.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构号 " + orgCode);
        }

        count = sysOrgService.countBy("name", orgName, true);
        if (count == 0) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构名字 " + orgName);
        }

        count = sysPositionService.countBy("name", rotationName, true);
        if (count == 0 || rotationName.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此岗位 " + rotationName);
        }

        if (durationOfEmployment == null) {
            errorMessages.add("第 " + index + " 行时间错误:从事相应重要岗位时间为 " + durationOfEmployment);
        }
        if (rotationExeTime == null) {
            errorMessages.add("第 " + index + " 行时间错误:轮岗截止日期为 " + rotationExeTime);
        }
        if (rotationDeadline == null) {
            errorMessages.add("第 " + index + " 行时间错误:轮岗执行时间 " + rotationDeadline);
        }
        if (planRotationDate == null) {
            errorMessages.add("第 " + index + " 行时间错误:计划轮岗日期 " + planRotationDate);
        }


//        if (orgName != null && specificNameOrgRotation != null && rotationName != null && counterImpPostRotation != null) {
//            Object result = rule.taRotationRule(entity);
//            errorMessages.add(result);
//        }

        return entity;
    }


    //    @Transactional(rollbackFor = Exception.class)
    public void saveEntityBatch(List<TaRotation> entityList) {
        // 实现逻辑：保存批量实体
        System.out.println("******************************entityList**************************************");
        System.out.println(entityList);
        for (TaRotation taRotation : entityList) {
            baseMapper.insert(taRotation);

        }
    }

    @Override
    public void selectGetWaring() {
//
////预警 消息
//        List<TaRotation> earlyWaringList = baseMapper.waring(localDate);
//
//        if (!earlyWaringList.isEmpty()) {
//            for (TaRotation item : earlyWaringList) {
//                TaMessage taMessage = new TaMessage();
//                String uuid = StringUtil.UUID();
//                taMessage.setMessageId(uuid);
//                taMessage.setSourceId(item.getRotationId());
//                StringBuilder sb = new StringBuilder(warningTmp);
//                sb.insert(Constants.numI, item.getEmployeeNum());
//                Integer i = item.getEmployeeNum().length() + Constants.nameI;
//                sb.insert(i, item.getEmployeeName());
//                taMessage.setContentSent(sb.toString());
//                taMessage.setSourceName("taRotation");
//                taMessage.setWaringType("waring");
//
//                Long count = taMessageService.countBy("source_id", item.getRotationId(), true);
//                if (count == 0) {
//                    taMessageMapper.insert(taMessage);
//                    insertIntoTaSending(item.getCreateUser(), uuid);
//                }
//
//            }
//        }
////提示消息
//        List<TaRotation> earlyPromptList = baseMapper.prompt(localDate);
//
//        if (earlyPromptList.size() != 0) {
//            for (TaRotation item : earlyPromptList) {
//                TaMessage taMessage = new TaMessage();
//                String uuid = StringUtil.UUID();
//                taMessage.setMessageId(uuid);
//                taMessage.setSourceId(item.getRotationId());
//                StringBuilder sb = new StringBuilder(promptTmp);
//                sb.insert(Constants.numI, item.getEmployeeNum());
//                Integer i = item.getEmployeeNum().length() + Constants.nameI;
//                sb.insert(i, item.getEmployeeName());
//                taMessage.setContentSent(sb.toString());
//                taMessage.setSourceName("taRotation");
//                taMessage.setWaringType("prompt");
//
//                Long count = taMessageService.countBy("source_id", item.getRotationId(), true);
//                if (count == 0) {
//                    taMessageMapper.insert(taMessage);
//                    insertIntoTaSending(item.getCreateUser(), uuid);
//                }
//
//            }
//        }

//        return;
        LocalDate localDate = LocalDate.now();

        // 预警消息处理
        messageHandle.handleMessages(localDate, warningTmp,WARNING_TYPE,MESSAGE_SOURCE_NAME ,baseMapper::waring);

        // 提示消息处理
        messageHandle.handleMessages(localDate,promptTmp, PROMPT_TYPE, MESSAGE_SOURCE_NAME ,baseMapper::prompt);
    }


    public List<Object> getErrorMessages() {
        return errorMessages;
    }
}

