package com.lyg.application.util;


import cn.dev33.satoken.util.SaResult;
import com.lyg.application.DTO.ErrorDto;
import com.lyg.application.entity.TaIncompatible;
import com.lyg.application.entity.TaRotation;
import com.lyg.application.mapper.TaIncompatibleMapper;
import com.lyg.application.mapper.TaRotationMapper;
import com.lyg.common.Constants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;

@Component
public class Rule {


    @Autowired
    TaIncompatibleMapper taIncompatibleMapper;
    @Autowired
    TaRotationMapper taRotationMapper;
    private static final String COMPATIBLE_TEXT = "根据不相容设置这两个岗位是相容的";

    //这是在controller中使用的
    public Object taRotationRule(TaRotation taRotation) {
        Map<String, String> params = new Hashtable<>();
        String specificOrgName = taRotation.getSpecificOrgName();
        String specificNameOrgRotation = taRotation.getSpecificNameOrgRotation();
        String counterImpPositions = taRotation.getCounterImpPositions();
        String counterImpPostRotation = taRotation.getCounterImpPostRotation();

        if (specificOrgName != null && specificNameOrgRotation != null && counterImpPositions != null && counterImpPostRotation != null) {
            LocalDate newDate = LocalDate.now();
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
            String passTime = newDate.format(formatter);
            params.put("oldOrgCode", taRotation.getSpecificOrgNum());
            params.put("newOrgCode", taRotation.getOrgNumJobRotation());
            params.put("primaryPost", taRotation.getCounterImpPositions());
            params.put("targetPost", taRotation.getCounterImpPostRotation());
            params.put("passTime", passTime);

            List<ErrorDto> result = siftRule(params);
            boolean isRulesCompatible = true;
            if (!result.isEmpty()) {
                isRulesCompatible = result.stream()
                        .allMatch(error -> error.getRules() != null && error.getRules().contains(COMPATIBLE_TEXT));


            }

            String message = (isRulesCompatible  ? "不相容" : "相容";


                int statusCode = 200; // HTTP状态码
                // 自定义消息
                SaResult response = CreateResponse.createResponse(statusCode, result, message);

                return response;

        }
        return SaResult.data(taRotation);
    }


    public List<ErrorDto> siftRule(Map<String, String> params) {
        List<TaIncompatible> taIncompatibleList = new ArrayList<>();
        if (params.get("oldOrgCode").equals(params.get("newOrgCode"))) {
//        普通规则
            taIncompatibleList = regularRules(params);
        }
//        三个月规则
        List<TaRotation> repelList = getMonthRules(params);


        RuleDetail ruleDetail = new RuleDetail();

        List<ErrorDto> result = ruleDetail.planRuleType(taIncompatibleList, repelList);


        return result;


    }


    public List<TaIncompatible> regularRules(Map<String, String> params) {
        return taIncompatibleMapper.getRegularRules(params, Constants.REGULAR_RULE);

    }


    public List<TaRotation> getMonthRules(Map<String, String> params) {
        List<TaRotation> repelList = new ArrayList<>();

        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");

        String primaryPost = params.get("primaryPost");
        String targetPost = params.get("targetPost");
        String passTime = params.get("passTime");
        LocalDate newDate = LocalDate.parse(passTime, formatter).minusMonths(3);

        List<String> oldPostList = taIncompatibleMapper.getMonthRulesPrimary(primaryPost, Constants.MONTH_RULE);
        List<String> newPostList = taIncompatibleMapper.getMonthRulesPrimary(targetPost, Constants.MONTH_RULE);

        if (oldPostList.size() == 0 && newPostList.size() == 0) {
            return repelList;
        } else {
            List<String> orgList = newPostList;//原来岗位+目标不相容岗位
            orgList.add(primaryPost);

            List<String> targetList = oldPostList;//目标岗位+原来不相容岗位
            targetList.add(targetPost);

            //拿到数据 不相容轮岗数据
            repelList = taRotationMapper.selectRepel(orgList, targetList, newDate, params);

            return repelList;
        }
    }
}

