package com.lyg.system.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.common.Constants;
import com.lyg.system.entity.SysMenu;
import com.lyg.framework.log.OpLog;
import com.lyg.system.service.SysMenuService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 菜单表;(sys_menu)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-2-5
 */
@Api(tags = "菜单表对象功能接口")
@RestController
@RequestMapping("/")
public class SysMenuController extends BaseController {

    @Autowired
    private SysMenuService sysMenuService;

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "菜单管理", action = "查询列表")
    @ApiOperation("分页查询")
    @GetMapping("/sysMenu")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) throws Exception {

        IPage<SysMenu> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByAsc("sort_no");

        IPage<SysMenu> result = sysMenuService.page(pg, queryWrapper);

        return SaResult.data(result);
    }
}