package com.lyg.system.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import java.util.List;
import com.lyg.common.Constants;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import com.lyg.framework.accesslimit.AccessLimit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.lyg.system.entity.SysPosition;
import com.lyg.system.service.SysPositionService;

 /**
 * 岗位表;(sys_position)表控制层
 * @author : http://njyunzhi.com
 * @date : 2024-3-6
 */
@Api(tags = "岗位表对象功能接口")
@RestController
@RequestMapping("/")
public class SysPositionController extends BaseController {
    
    @Autowired
    private SysPositionService sysPositionService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "岗位表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysPosition/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(sysPositionService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "岗位表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/sysPosition")
    public SaResult list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                         @ApiParam("岗位名字") @RequestParam(value ="name", required = false) String name,
                         @ApiParam("正序排列") @RequestParam(value ="sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value ="sortDesc", defaultValue = "create_date") String sortDesc) throws Exception {
        
        IPage<SysPosition> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysPosition> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtil.isNotEmpty(name),"name",name);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<SysPosition> result = sysPositionService.page(pg, queryWrapper);
        
        return SaResult.data(result);
    }
    
    /** 
     * 新增数据
     *
     * @param sysPosition 实例对象
     * @return 实例对象
     */
    @OpLog(module = "岗位表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/sysPosition")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody SysPosition sysPosition) throws Exception {
        sysPositionService.save(sysPosition);
        return SaResult.data(sysPosition);
    }
    
    /** 
     * 更新数据
     *
     * @param sysPosition 实例对象
     * @return 实例对象
     */
    @OpLog(module = "岗位表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/sysPosition/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody SysPosition sysPosition,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        sysPosition.setPositionId(id);
        sysPositionService.updateById(sysPosition);
        return SaResult.data(sysPosition);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "岗位表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysPosition/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        sysPositionService.removeById(id);
        return SaResult.data("success");
    }
}