package com.lyg.system.controller;

import cn.dev33.satoken.sso.SaSsoProcessor;
import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.common.Constants;
import com.lyg.common.util.StringUtil;
import com.lyg.system.entity.SysUser;
import com.lyg.framework.log.OpLog;
import com.lyg.system.service.SysMenuService;
import com.lyg.system.service.SysRoleService;
import com.lyg.system.service.SysUserRoleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * 用户表;(sys_user)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-1-27
 */
@Api(tags = "用户表对象功能接口")
@RestController
@RequestMapping("/")
public class SysUserController extends BaseController {

    @Autowired
    SysRoleService sysRoleService;

    @Autowired
    SysUserRoleService sysUserRoleService;

    @Autowired
    SysMenuService sysMenuService;


    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "查询详情")
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysUser/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        SysUser sysUser = sysUserService.getById(id);
        if (null == sysUser || sysUser.getStatus() == Constants.STATUS_DELETE) {
            return SaResult.error("用户不存在");
        }

        sysUser.setRolesList(sysRoleService.getByUser(id));
        sysUser.setMenuList(sysMenuService.getByUser(id));
        return SaResult.data(sysUser);
    }


    /**
     * 查询当前人员
     *
     * @param
     * @return 实例对象
     */
    @ApiOperation("查询当前人员")
    @GetMapping("/sysUser/current")
    public SaResult current(@ApiParam("sso ticket") @RequestParam(value = "ticket", required = false) String ticket,
                            @ApiParam("sso ticket") @RequestParam(value = "appid", required = false) String appid) throws Exception {
        Map<String, Object> res = new HashMap<>();
        Boolean isLogin= StpUtil.isLogin();
        if (!isLogin) {

            if (!StringUtil.isEmpty(ticket)) {
                // 如果是 SSO 登录
                Object loginId = SaSsoProcessor.instance.checkTicket(ticket, "/sysUser/current");
                if(loginId != null) {
                    StpUtil.login(loginId, appid);
                    res.put("token", StpUtil.getTokenValue());
                } else {
                    return SaResult.error("无效 Ticket").setCode(401);
                }
            } else {
                return SaResult.error("请先登录").setCode(401);
            }
        }

        SysUser sysUser = currentUser();

        sysUser.setRolesList(sysRoleService.getByUser(sysUser.getUserId()));
        sysUser.setMenuList(sysMenuService.getByUser(sysUser.getUserId()));

        res.put("user", sysUser);
        return SaResult.data(res);
    }


//    /**
//     * 获取行信端当前人员
//     *
//     * @param
//     * @return 实例对象
//     */
//    @ApiOperation("获取行信端当前人员")
//    @GetMapping("/h5/sysUser/current")
//    public SaResult hxCurrent() throws Exception {
//        SysUser sysUser = currentHxUser();
//
//        return SaResult.data(sysUser);
//    }


    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "人员管理", action = "查询列表")
    @ApiOperation("分页查询")
    @GetMapping("/sysUser")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("姓名") @RequestParam(value = "name", required = false) String name,
                         @ApiParam("机构") @RequestParam(value = "orgId", required = false) String orgId,
                         @ApiParam("岗位ID") @RequestParam(value = "positionId", required = false) String positionId,
                         @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone) throws Exception {

        IPage<SysUser> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtil.isEmpty(name), "name", name);
        queryWrapper.eq(!StringUtil.isEmpty(orgId), "org_id", orgId);
        queryWrapper.eq(!StringUtil.isEmpty(positionId), "position_id", positionId);
        queryWrapper.like(!StringUtil.isEmpty(phone), "phone", phone);
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.ne("user_id", Constants.ROOT_ID);
        queryWrapper.orderByDesc("create_date");
        IPage<SysUser> result = sysUserService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param sysUser 实例对象
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "新增数据")
    @ApiOperation("新增数据")
    @PostMapping("/sysUser")
    public SaResult add(@ApiParam("对象实体") @RequestBody SysUser sysUser) throws Exception {
        if (StringUtil.isEmpty(sysUser.getOrgId())) {
            return SaResult.error("请设置所属机构");
        }

        sysUserService.mergeData(sysUser);
        return SaResult.data(sysUserService.getById(sysUser.getUserId()));
    }

     /**
      * 更新状态
      *
      * @param id 实例ID
      * @return 实例对象
      */
     @OpLog(module = "人员管理", action = "更新状态")
     @ApiOperation("更新状态")
     @PutMapping("/sysUser/{id}/status")
     public SaResult edit(@ApiParam("对象ID") @PathVariable String id,
                              @ApiParam("页码") @RequestParam(value = "status") Integer status) throws Exception {

         SysUser sysUser = sysUserService.getById(id);
         sysUser.setStatus(status);

         sysUserService.updateById(sysUser);
         return SaResult.data(sysUser);
     }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "人员管理", action = "删除数据")
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysUser/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        sysUserService.removeLogicById(id);

        // 授权角色
        sysUserRoleService.removeByMap(new HashMap<String, Object>(){{
            put("user_id", id);
        }});

        return SaResult.ok("success");
    }
}