package com.lyg.system.service.impl;

import com.lyg.common.Constants;
import com.lyg.common.util.StringUtil;
import com.lyg.system.entity.SysRole;
import com.lyg.system.entity.SysUser;
import com.lyg.system.entity.SysUserRole;
import com.lyg.system.mapper.SysUserMapper;
import com.lyg.system.mapper.SysUserRoleMapper;
import com.lyg.system.service.SysUserService;
import com.lyg.system.service.request.Fetch;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 用户表;(sys_user)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-1-27
 */
@Service
public class SysUserServiceImpl extends BaseServiceImpl<SysUserMapper, SysUser> implements SysUserService {

    @Autowired
    SysUserRoleMapper sysUserRoleMapper;

    @Value("${yz.appid}")
    String appid;

    @Autowired
    Fetch fetch;

    @Override
    public void mergeData(SysUser sysUser) throws Exception {
        if (StringUtil.isEmpty(sysUser.getName())) {
            throw new Exception("用户名称不能为空");
        }

        if (StringUtil.isEmpty(sysUser.getUserId())) {
            throw new Exception("请从认证中心拉取用户");
        }

        // 尝试授权认证中心人员
        try {
            fetch.post(String.format("/api/sso/user/%s/app/%s", sysUser.getUserId(), appid), null, null).exec();
        } catch (Exception e) {
            e.printStackTrace();
            throw new Exception("授权人员应用权限失败, 请重试");
        }

        //
        SysUser origin = getById(sysUser.getUserId());
        LocalDateTime now = LocalDateTime.now();

        // 用户表
        if (null == origin) {
            if (null == sysUser.getStatus()) {
                sysUser.setStatus(Constants.STATUS_NORMAL);
            }

            sysUser.setCreateDate(now);
            save(sysUser);
        } else {
            if (Constants.STATUS_DELETE == origin.getStatus()) {
                sysUser.setStatus(Constants.STATUS_NORMAL);
            }

            updateById(sysUser);
        }

        // 授权角色
        List<SysRole> rolesList = sysUser.getRolesList();
        if (null == rolesList || rolesList.size() == 0) {
            sysUserRoleMapper.deleteByMap(new HashMap<String, Object>() {{
                put("user_id", sysUser.getUserId());
            }});
        } else {
            List<String> idList = new ArrayList<>();
            for (SysRole role : rolesList) {
                SysUserRole item = new SysUserRole();
                item.setUserId(sysUser.getUserId());
                item.setRoleId(role.getRoleId());

                SysUserRole exists = sysUserRoleMapper.getByUserAndRole(sysUser.getUserId(), role.getRoleId());
                if (null != exists) {
                    item.setId(exists.getId());
                } else {
                    sysUserRoleMapper.insert(item);
                }

                idList.add(item.getId());
            }

            // 去除垃圾数据
            sysUserRoleMapper.deleteNotIn(sysUser.getUserId(), idList);
        }
    }

    @Override
    public SysUser getByHxId(String hxId) {
        return getExistBy("hx_id", hxId, false, true);
    }
}